pub enum Error {
AndroidEnvironment,
MalformedUri,
NoHandler,
NotMainThread,
Unknown,
}Expand description
Errors encountered when opening a URI.
Variants
AndroidEnvironment
Could not acquire the android environment.
See the robius-android-env crate for more details.
MalformedUri
The provided URI was malformed or otherwise invalid.
NoHandler
No handler was available to open the URI.
NotMainThread
The URI was not opened because it must be called on the main UI thread.
Unknown
An unknown error occurred.
Note that on certain platforms if a handler is not available this error variant will be returned, as the error returned by the operating system is not fine-grained enough.