Uri

Struct Uri 

pub struct Uri<'a, 'b> { /* private fields */ }
A uniform resource identifier.

Implementations

Source

impl<'a, 'b> Uri<'a, 'b>

pub fn new(s: &'a str) -> Self

Constructs a new URI.

Examples found in repository?
examples/open_tel.rs (line 2)
1fn main() {
2    robius_open::Uri::new("tel:+61 0400 000 000")
3        .action("ACTION_DIAL")
4        .open()
5        .unwrap();
6}
More examples
Hide additional examples
examples/open_mail.rs (line 2)
1fn main() {
2    robius_open::Uri::new("mailto:test@example.com")
3        .action("ACTION_MAIL")
4        .open()
5        .unwrap();
6}
examples/open_url.rs (line 2)
1fn main() {
2    robius_open::Uri::new("https://github.com/project-robius")
3        .action("ACTION_VIEW")
4        .open()
5        .unwrap();
6}
pub fn action(self, action: &'b str) -> Self

Sets the action to perform with this URI.

This only has an effect on Android, and corresponds to an action activity. By default, it is set to "ACTION_VIEW".

Examples
Uri::new("tel:+61 123 456 789")
    .action("ACTION_DIAL")
    .open()
    .expect("failed to open telephone URI");
Examples found in repository?
examples/open_tel.rs (line 3)
1fn main() {
2    robius_open::Uri::new("tel:+61 0400 000 000")
3        .action("ACTION_DIAL")
4        .open()
5        .unwrap();
6}
More examples
Hide additional examples
examples/open_mail.rs (line 3)
1fn main() {
2    robius_open::Uri::new("mailto:test@example.com")
3        .action("ACTION_MAIL")
4        .open()
5        .unwrap();
6}
examples/open_url.rs (line 3)
1fn main() {
2    robius_open::Uri::new("https://github.com/project-robius")
3        .action("ACTION_VIEW")
4        .open()
5        .unwrap();
6}
pub fn open(self) -> Result<()>

Opens this URI.

This must be called on the main UI thread, or it will return Error::NotMainThread.

Note that the returned Result does not necessarily indicate whether the URI was successfully opened by the system. For that purpose, you should use Self::open_with_completion().

Examples found in repository?
examples/open_tel.rs (line 4)
1fn main() {
2    robius_open::Uri::new("tel:+61 0400 000 000")
3        .action("ACTION_DIAL")
4        .open()
5        .unwrap();
6}
More examples
Hide additional examples
examples/open_mail.rs (line 4)
1fn main() {
2    robius_open::Uri::new("mailto:test@example.com")
3        .action("ACTION_MAIL")
4        .open()
5        .unwrap();
6}
examples/open_url.rs (line 4)
1fn main() {
2    robius_open::Uri::new("https://github.com/project-robius")
3        .action("ACTION_VIEW")
4        .open()
5        .unwrap();
6}
pub fn open_with_completion<F>(self, on_completion: F) -> Result<()>
where F: Fn(bool) + Send + 'static,

Opens this URI, with a callback for determining if the URI was successfully opened.

This must be called on the main UI thread, or it will return Error::NotMainThread.

Note that the returned Result does not necessarily indicate whether the URI was successfully opened by the system. For that purpose, the given on_completion callback will be called with a boolean indicating whether the URI was successfully opened. Note that the callback may be not be called at all, but should typically be called upon success.

Thus, the URI was not successfully opened if this function returns an error, OR if the on_completion callback is invoked with false.